magnitude_change_func: magnitude_change_func

View source: R/fisher_metrics.R

magnitude_change_funcR Documentation

magnitude_change_func

Description

Calculates the differences between two point with a lag of 1:lags

Usage

magnitude_change_func(fisher_df, lags = 10)

Arguments

fisher_df

A fisher output containing FI_means and time_windows

lags

the number of lags to calculate the differences between

Value

a single row tibble with the max increase and max decrease found accros all lags


UoA-eResearch/fisheR documentation built on July 8, 2023, 5:06 p.m.