View source: R/fisher_metrics.R
| magnitude_change_func | R Documentation |
Calculates the differences between two point with a lag of 1:lags
magnitude_change_func(fisher_df, lags = 10)
fisher_df |
A fisher output containing FI_means and time_windows |
lags |
the number of lags to calculate the differences between |
a single row tibble with the max increase and max decrease found accros all lags
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.